@@ -1,5 +1,6 @@
 # flake8: noqa
 
+from .alerts import Alerts
 from .api import Api
 from .auth import Auth
 from .db import Db
@@ -7,6 +8,7 @@ from .debug import Debug
 from .hydra import Hydra
 from .missions import Missions
 from .notifications import Notifications
+from .scratchspace import Scratchspace
 from .targets import Targets
 from .templates import Templates
 from .transactions import Transactions
