@@ -21,8 +21,10 @@ class Hydra(Plugin):
     def get_hydra(self, page=1, max_page=5, update_db=True, **kwargs):
         """Get Hydra results for target identified using kwargs (codename='x', slug='x', etc.)"""
         max_page = 1000 if max_page == 0 else max_page
-        target = self.db.find_targets(**kwargs)[0]
         results = list()
+        targets = self.db.find_targets(**kwargs)
+        if targets:
+            target = targets[0]
         if target:
             query = {
                 'page': page,
